==> haskell-test-framework-quickcheck2-0.3.0.6-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-GxQqf0bYfKUJ06KhxJE0hI
key:                  test-framework-quickcheck2-0.3.0.6-GxQqf0bYfKUJ06KhxJE0hI
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  856fd24d9206ca362917fa172d4f2824
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-GxQqf0bYfKUJ06KhxJE0hI
depends:
    QuickCheck-2.14.3-ByUzmICu9MK1GnGhfACscM base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.3-9I8x2ZdyyN6LUBxcAUCXuW
    test-framework-0.8.2.2-1QU3WWP05IVLb1dUSnQgbz

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.6-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-6qfNYprR5BIEpMjVe7ozLa
key:                  test-framework-quickcheck2-0.3.0.6-6qfNYprR5BIEpMjVe7ozLa
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  060b160796b2e7628c3ae809f538d4cb
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-6qfNYprR5BIEpMjVe7ozLa
depends:
    QuickCheck-2.14.3-GX4SHMaU8sh5Q2eJfBXwpY base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.3-5ACjslZ7ju38gzfSozRJEo
    test-framework-0.8.2.2-15kRDcDGbWJ8WmzXq5gIil

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
